
This Python package provides an alternative approach to working with Tcl/Tk GUI code from Python.  It makes use of tkinter to communicate with Tcl/Tk, but does not otherwise use the class wrappers provided by tkinter.

It is not presently documented, but there are [hints on how to use it available in the repository's notes.txt file.](https://raw.githubusercontent.com/LionKimbro/liontk/main/liontk/notes.txt)
